@@ -17,9 +17,11 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#define _XOPEN_SOURCE 700
+
 #include <config.h>
 #include <pwd.h>
 #include <stdio.h>
@@ -41,13 +43,6 @@
 #include "fr-init.h"
 
 
-#ifndef HAVE_MKDTEMP
-#include "mkdtemp.h"
-#endif
-
-#define BUF_SIZE 4096
-#define FILE_PREFIX    "file://"
-#define FILE_PREFIX_L  7
 #define SPECIAL_DIR(x) ((strcmp ((x), "..") == 0) || (strcmp ((x), ".") == 0))
 
 
@@ -755,8 +750,7 @@ path_list_free (GList *path_list)
 {
 	if (path_list == NULL)
 		return;
-	g_list_foreach (path_list, (GFunc) g_free, NULL);
-	g_list_free (path_list);
+	g_list_free_full (path_list, g_free);
 }
 
 
@@ -909,12 +903,12 @@ get_temp_work_dir (const char *parent_folder)
 {
 	guint64  max_size = 0;
 	char    *best_folder = NULL;
-	int      i;
 	char    *template;
 	char    *result = NULL;
 
 	if (parent_folder == NULL) {
 		/* find the folder with more free space. */
+		int i;
 
 		for (i = 0; try_folder[i] != NULL; i++) {
 			char    *folder;
