@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <stdlib.h>
@@ -393,7 +393,8 @@ fr_command_alz_get_type ()
 			NULL,
 			sizeof (FrCommandAlz),
 			0,
-			(GInstanceInitFunc) fr_command_alz_init
+			(GInstanceInitFunc) fr_command_alz_init,
+			NULL
 		};
 
 		type = g_type_register_static (FR_TYPE_COMMAND,
