@@ -140,8 +140,11 @@ process_line (char     *line,
 	}
 	g_free (name);
 	name = g_filename_from_utf8 (fdata->original_path, -1, NULL, NULL, NULL);
-	if (name)
-		fdata->original_path = name;
+	if (name) {
+		fdata->original_path = g_strdup (name);
+		fdata->free_original_path = TRUE;
+	}
+	g_free (name);
 
 	if (fields[1] != NULL)
 		fdata->link = g_strdup (fields[1]);
